#### `responsive` property

Array of objects in the form of `{ breakpoint: int, settings: { ... } }` The breakpoint _int_ is the `maxWidth` so the settings will be applied when resolution is below this value. Breakpoints in the array should be ordered from smallest to greatest. Use 'unslick' in place of the settings object to disable rendering the carousel at that breakpoint. Example: `[ { breakpoint: 768, settings: { slidesToShow: 3 } }, { breakpoint: 1024, settings: { slidesToShow: 5 } }, { breakpoint: 100000, settings: 'unslick' } ]`

### Custom next/prev arrows

To customize the next/prev arrow elements, simply create new React components and set them
as the values of nextArrow and prevArrow.

```js
class LeftNavButton extends React.Component {
  render() {
    return <button {...this.props}>Next</button>;
  }
}
```

Important: be sure that you pass your component's props to your clickable element
like the example above. If you don't, your custom component won't trigger the click handler.

You can also set `onClick={this.props.onClick}` if you only want to set the click handler.

### Flexbox support

If you have flex property on container div of slider, add below css

```css
* {
  min-height: 0;
  min-width: 0;
}
```

### Test Setup

If you try to run tests with jest in a project that uses react-slick, you may run into this error

```
matchMedia not present, legacy browsers require a polyfill
```

To fix this issue add below snippet in test-setup.js

```js
window.matchMedia =
  window.matchMedia ||
  function() {
    return {
      matches: false,
      addListener: function() {},
      removeListener: function() {}
    };
  };
```

and add below jest config in package.json

```json
"jest": {
    "setupFiles": ["test-setup.js"]
}
```

### Polyfills for old IE support

`matchMedia` support from [media-match](https://github.com/weblinc/media-match)
